# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined


class UserUpdateEventAllOfPayload(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'user': 'User',
        'reason': 'str',
        'source': 'SourceWebhook'
    }

    attribute_map = {
        'user': 'user',
        'reason': 'reason',
        'source': 'source'
    }

    nulls = set()

    def __init__(self, user=None, reason=None, source=None, local_vars_configuration=None):  # noqa: E501
        """UserUpdateEventAllOfPayload - a model defined in OpenAPI"""  # noqa: E501
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._user = None
        self._reason = None
        self._source = None
        self.discriminator = None

        if user is not None:
            self.user = user
        if reason is not None:
            self.reason = reason
        if source is not None:
            self.source = source

    @property
    def user(self):
        """Gets the user of this UserUpdateEventAllOfPayload.  # noqa: E501

        The updated user.  # noqa: E501

        :return: The user of this UserUpdateEventAllOfPayload.  # noqa: E501
        :rtype: User
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this UserUpdateEventAllOfPayload.

        The updated user.  # noqa: E501

        :param user: The user of this UserUpdateEventAllOfPayload.  # noqa: E501
        :type: User
        """

        self._user = user

    @property
    def reason(self):
        """Gets the reason of this UserUpdateEventAllOfPayload.  # noqa: E501

        The reason why the user was updated, if applicable. * `authentication` - An anonymous user became an [identified](https://docs.smooch.io/guide/intro-to-users/) user. * `localeDetection` - A user was updated as a result of automated locale detection on messages sent.   # noqa: E501

        :return: The reason of this UserUpdateEventAllOfPayload.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this UserUpdateEventAllOfPayload.

        The reason why the user was updated, if applicable. * `authentication` - An anonymous user became an [identified](https://docs.smooch.io/guide/intro-to-users/) user. * `localeDetection` - A user was updated as a result of automated locale detection on messages sent.   # noqa: E501

        :param reason: The reason of this UserUpdateEventAllOfPayload.  # noqa: E501
        :type: str
        """
        allowed_values = ["authentication", "localeDetection"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and reason not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `reason` ({0}), must be one of {1}"  # noqa: E501
                .format(reason, allowed_values)
            )

        self._reason = reason

    @property
    def source(self):
        """Gets the source of this UserUpdateEventAllOfPayload.  # noqa: E501

        The source of the creation.  # noqa: E501

        :return: The source of this UserUpdateEventAllOfPayload.  # noqa: E501
        :rtype: SourceWebhook
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this UserUpdateEventAllOfPayload.

        The source of the creation.  # noqa: E501

        :param source: The source of this UserUpdateEventAllOfPayload.  # noqa: E501
        :type: SourceWebhook
        """

        self._source = source

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserUpdateEventAllOfPayload):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserUpdateEventAllOfPayload):
            return True

        return self.to_dict() != other.to_dict()
