# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined


class AppleMessageOverridePayload(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'payload': 'object',
        'with_capabilities': 'list[str]'
    }

    attribute_map = {
        'payload': 'payload',
        'with_capabilities': 'withCapabilities'
    }

    nulls = set()

    def __init__(self, payload=None, with_capabilities=None, local_vars_configuration=None):  # noqa: E501
        """AppleMessageOverridePayload - a model defined in OpenAPI"""  # noqa: E501
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._payload = None
        self._with_capabilities = None
        self.discriminator = None

        if payload is not None:
            self.payload = payload
        if with_capabilities is not None:
            self.with_capabilities = with_capabilities

    @property
    def payload(self):
        """Gets the payload of this AppleMessageOverridePayload.  # noqa: E501


        :return: The payload of this AppleMessageOverridePayload.  # noqa: E501
        :rtype: object
        """
        return self._payload

    @payload.setter
    def payload(self, payload):
        """Sets the payload of this AppleMessageOverridePayload.


        :param payload: The payload of this AppleMessageOverridePayload.  # noqa: E501
        :type: object
        """

        self._payload = payload

    @property
    def with_capabilities(self):
        """Gets the with_capabilities of this AppleMessageOverridePayload.  # noqa: E501

        List of capabilities needed for the override message to be received by the end user.   `LIST` : for list picker; `TIME` : for time picker; `FORM` : for form; `QUICK` : for quick reply; `AUTH2` : for authentication   # noqa: E501

        :return: The with_capabilities of this AppleMessageOverridePayload.  # noqa: E501
        :rtype: list[str]
        """
        return self._with_capabilities

    @with_capabilities.setter
    def with_capabilities(self, with_capabilities):
        """Sets the with_capabilities of this AppleMessageOverridePayload.

        List of capabilities needed for the override message to be received by the end user.   `LIST` : for list picker; `TIME` : for time picker; `FORM` : for form; `QUICK` : for quick reply; `AUTH2` : for authentication   # noqa: E501

        :param with_capabilities: The with_capabilities of this AppleMessageOverridePayload.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["LIST", "TIME", "FORM", "QUICK", "AUTH2"]  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                not set(with_capabilities).issubset(set(allowed_values))):  # noqa: E501
            raise ValueError(
                "Invalid values for `with_capabilities` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(with_capabilities) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._with_capabilities = with_capabilities

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AppleMessageOverridePayload):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AppleMessageOverridePayload):
            return True

        return self.to_dict() != other.to_dict()
